<?php
if ( ! function_exists( 'favita_paging_nav' ) ) :
function favita_paging_nav() {
	global $wp_query, $wp_rewrite;
	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 ) {
		return;
	}
	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );
	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}
	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';
	$format  = $wp_rewrite->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $wp_rewrite->using_permalinks() ? user_trailingslashit( $wp_rewrite->pagination_base . '/%#%', 'paged' ) : '?paged=%#%';
	// Set up paginated links.
	$pagination = paginate_links( array(
		'base'     => $pagenum_link,
		'format'   => $format,
		'total'    => $wp_query->max_num_pages,
		'current'  => $paged,
		'mid_size' => 1,
		'add_args' => array_map( 'urlencode', $query_args ),
		'prev_text' => esc_html__( 'Previous', 'favita' ),
		'next_text' => esc_html__( 'Next', 'favita' ),
		'type'      => 'list'
	) );
	if ( $pagination ) :
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'favita' ); ?></h1>
		<div class="pagination loop-pagination">
			<?php echo wp_kses($pagination,'social'); ?>
		</div><!-- .pagination -->
	</nav><!-- .navigation -->
	<?php
	endif;
}
endif;
if ( ! function_exists( 'favita_post_nav' ) ) :
function favita_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );
	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<div class="prevNextArticle box">
		<div class="previousArticle">
			<?php previous_post_link( '%link', '<div class="hoverExtend active"><i class="zmdi zmdi-long-arrow-left"></i><span>'.esc_html__('Previous post','favita').'</span></div>' ); ?>
		</div>
		<div class="nextArticle">
			<?php next_post_link( '%link', '<div class="hoverExtend active"><span>'.esc_html__('Next post','favita').'</span><i class="zmdi zmdi-long-arrow-right"></i></div>' ); ?>
		</div>
	</div><!-- Previous / next article -->
	<?php
}
endif;
function favita_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'favita_category_count' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );
		// Count the number of categories that are attached to the posts
		$all_the_cool_cats = count( $all_the_cool_cats );
		set_transient( 'favita_category_count', $all_the_cool_cats );
	}
	if ( 1 !== (int) $all_the_cool_cats ) {
		return true;
	} else {
		return false;
	}
}
function favita_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'favita_category_count' );
}
add_action( 'edit_category', 'favita_category_transient_flusher' );
add_action( 'save_post',     'favita_category_transient_flusher' );
if ( ! function_exists( 'favita_single_author' ) ) :
function favita_single_author(){
	global $favita_settings,$post;
	$user_description = get_user_meta( get_the_author_meta( 'ID' ), 'description', true ); ?>
	<?php if (favita_get_config('archives-author') && $user_description ) { ?>
		<div class="entry-meta-author">
			<div class="author-avatar">
				<span class="author-image"><?php echo get_avatar( get_the_author_meta( 'ID' ), 80); ?> </span>
			</div>
			<div class="author-info">
				<span class="author-link"><?php the_author_posts_link(); ?></span>
				<span class="author-description"><?php the_author_meta('description'); ?></span>
			</div>
		</div>	
	<?php } ?>
<?php }
endif;
if ( ! function_exists( 'favita_post_thumbnail' ) ) :
function favita_post_thumbnail() {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}
	if ( is_singular() ) : ?>
		<div class="post-thumbnail">
		<?php the_post_thumbnail( 'favita-full-width' ); ?>
		</div>
	<?php else : ?>
		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
		<?php the_post_thumbnail( 'favita-full-width' ); ?>
		</a>
	<?php endif; // End is_singular()
}
endif;
function favita_page_title() {
	global $post, $favita_settings,$wp_query;
	$enable_page_title = isset($favita_settings['page_title']) ? $favita_settings['page_title'] : true ;
	if($enable_page_title){
		$bg = isset($favita_settings['page_title_bg']['url']) ? $favita_settings['page_title_bg']['url'] : "";
		$class_empty = (empty($bg)) ? " empty-image" : "";
		?>
		<div class="page-title bwp-title<?php echo esc_attr($class_empty); ?>" <?php echo (!empty($bg) ? ' style="background-image:url(' . esc_url( $bg ) . ');"' : ''); ?>>
			<div class="container" >
				<?php if(!is_single() ) :  ?>
					<h1>
						<?php						
						if( is_category() ) :
							single_cat_title();							
						elseif ( is_tax() ) :
							single_tag_title();	
						elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) :
							esc_html_e( 'Galleries', 'favita' );
						elseif ( is_tax( 'post_format', 'post-format-image' ) ) :
							esc_html_e( 'Images', 'favita' );
						elseif ( is_tax( 'post_format', 'post-format-video' ) ) :
							esc_html_e( 'Videos', 'favita' );
						elseif ( is_tax( 'post_format', 'post-format-quote' ) ) :
							esc_html_e( 'Quotes', 'favita' );
						elseif ( is_tax( 'post_format', 'post-format-audio' ) ) :
							esc_html_e( 'Audios', 'favita' );
						elseif ( is_archive() && is_author() ) :
							esc_html_e( 'Posts by " ', 'favita' ) . the_author() . esc_html_e(' " ','favita');
						elseif ( function_exists('is_shop') && is_shop() ) :							
							esc_html_e( 'Shop', 'favita' );
						elseif ( is_archive() && !is_search()) :						
							the_archive_title();
						elseif ( is_search() ) :
							printf( esc_html__( 'Search for: %s', 'favita' ), get_search_query() );
						elseif ( is_404() ) :
							esc_html_e( '404 Error', 'favita' );
						elseif ( is_singular( 'knowledge' ) ) :
							esc_html_e( 'Knowledge Base', 'favita' );
						elseif ( is_home() ) :
							esc_html_e( 'Posts', 'favita' );
						else :
							echo get_the_title();
						endif;
						?>
					</h1>
				<?php endif; ?>
				<?php $enable_breadcrumb = isset($favita_settings['breadcrumb']) ? $favita_settings['breadcrumb'] : true ; ?>
				<?php if($enable_breadcrumb) : ?>
					<?php
						if(function_exists('is_woocommerce') && is_woocommerce()){
							if (class_exists("WCV_Vendors") && WCV_Vendors::is_vendor_page()){
								get_template_part( 'breadcrumb');
							}else{
								favita_woocommerce_breadcrumb();
							}
						}else{
							get_template_part( 'breadcrumb');
						}		
					?>			
				<?php endif; ?>
			</div><!-- .container -->
		</div><!-- Page Title -->
	<?php } ?>
<?php }
if ( ! function_exists( 'favita_single_posted_on' ) ) :
function favita_single_posted_on() { 
	global $favita_settings,$post; ?>
	<div class="entry-meta">
		<div class="entry-date"><?php echo favita_time_link(); ?></div>
		<!-- Categories -->
		<?php $categories_list = get_the_category_list( __( ', ', 'favita' ) );
		if ( $categories_list ) : ?>
			<span class="cat-links">
				<?php					
				echo wp_kses_post( $categories_list );
				?>
			</span>
		<?php endif; ?>
		<!-- End if categories. -->
	</div>			
<?php }
endif;
if ( ! function_exists( 'favita_single_posted_on_2' ) ) :
function favita_single_posted_on_2(){
	global $favita_settings,$post; ?>
		<div class="entry-meta">
			<?php if (favita_get_config('archives-author')) { ?>
				<span class="entry-meta-link"><i class="fa fa-user"></i><?php the_author_posts_link(); ?></span>
			<?php } ?>
			<a class="comments-link" href="<?php echo esc_attr('#respond'); ?>">
				<i class="fa fa-comment-o"></i>
				<?php 
				$comment_count =  wp_count_comments(get_the_ID())->total_comments;
				if($comment_count > 0) {
				?>
					<?php if($comment_count == 1){?>
						<?php echo esc_attr($comment_count) .'<span>'. esc_html__(' Comment', 'favita').'</span>'; ?>
					<?php }else{ ?>
						<?php echo esc_attr($comment_count) .'<span>'. esc_html__(' Comments', 'favita').'</span>'; ?>
					<?php } ?>
				<?php }else{ ?>
					<?php echo esc_attr($comment_count) .'<span>'. esc_html__(' Comments', 'favita').'</span>'; ?>
				<?php } ?>
			</a>
			<?php if ( favita_get_config('show-count-views',false) ) { ?>
				<span class="entry-meta-views">
				<i class="fa fa-eye"></i>
				<?php $view_count = favita_get_post_views(get_the_ID()); ?>
					<?php if($view_count > 0) { ?>
						<?php if($view_count == 1){?>
							<?php echo esc_attr($view_count) .'<span>'. esc_html__(' View', 'favita').'</span>'; ?>
						<?php }else{ ?>
							<?php echo esc_attr($view_count) .'<span>'. esc_html__(' Views', 'favita').'</span>'; ?>
						<?php } ?>
					<?php }else{ ?>
						<?php echo esc_attr($view_count) .'<span>'. esc_html__(' Views', 'favita').'</span>'; ?>
					<?php } ?>
				</span>
			<?php } ?>
		</div>
<?php }
endif;
if ( ! function_exists( 'favita_posted_on' ) ) :
function favita_posted_on() { 
	global $favita_settings,$post; ?>
		<div class="entry-meta">
			<?php if (favita_get_config('archives-author')) { ?>
				<span class="entry-meta-link"><i class="fa fa-user"></i><?php the_author_posts_link(); ?></span>
			<?php } ?>
			<span class="comments-link">
				<i class="fa fa-comment-o"></i>
				<?php 
					$comment_count =  wp_count_comments(get_the_ID())->total_comments;
					if($comment_count > 0) {
				?>
					<?php if($comment_count == 1){?>
						<?php echo esc_attr($comment_count).'<span>'. esc_html__(' Comment', 'favita').'</span>'; ?>
					<?php }else{ ?>
						<?php echo esc_attr($comment_count).'<span>'. esc_html__(' Comments', 'favita').'</span>'; ?>
					<?php } ?>
				<?php }else{ ?>
					<?php echo esc_attr($comment_count).'<span>'. esc_html__(' Comments', 'favita').'</span>'; ?>
				<?php } ?>
			</span>
			<?php if ( favita_get_config('show-count-views',false) ) { ?>
				<span class="entry-meta-views">
				<i class="fa fa-eye"></i>
				<?php $view_count = favita_get_post_views(get_the_ID()); ?>
					<?php if($view_count > 0) { ?>
						<?php if($view_count == 1){?>
							<?php echo esc_attr($view_count) .'<span>'. esc_html__(' View', 'favita').'</span>'; ?>
						<?php }else{ ?>
							<?php echo esc_attr($view_count) .'<span>'. esc_html__(' Views', 'favita').'</span>'; ?>
						<?php } ?>
					<?php }else{ ?>
						<?php echo esc_attr($view_count) .'<span>'. esc_html__(' Views', 'favita').'</span>'; ?>
					<?php } ?>
				</span>
			<?php } ?>
		</div>
<?php }
endif;
if ( ! function_exists( 'favita_posted_on_2' ) ) :
function favita_posted_on_2() { 
	global $favita_settings,$post; ?>
		<div class="entry-meta">
			<div class="post-date">
				<i class="fa fa-clock-o"></i>
				<span><?php echo favita_time_link(); ?></span>
			</div>
			<?php if (favita_get_config('archives-author')) { ?>
				<span class="entry-meta-link"><i class="fa fa-user"></i><?php the_author_posts_link(); ?></span>
			<?php } ?>
			<span class="comments-link">
				<i class="fa fa-comment-o"></i>
				<?php 
					$comment_count =  wp_count_comments(get_the_ID())->total_comments;
					if($comment_count > 0) {
				?>
					<?php if($comment_count == 1){?>
						<?php echo esc_attr($comment_count).'<span>'. esc_html__(' Comment', 'favita').'</span>'; ?>
					<?php }else{ ?>
						<?php echo esc_attr($comment_count).'<span>'. esc_html__(' Comments', 'favita').'</span>'; ?>
					<?php } ?>
				<?php }else{ ?>
					<?php echo esc_attr($comment_count).'<span>'. esc_html__(' Comments', 'favita').'</span>'; ?>
				<?php } ?>
			</span>
			<?php if ( favita_get_config('show-count-views',false) ) { ?>
				<span class="entry-meta-views">
				<i class="fa fa-eye"></i>
				<?php $view_count = favita_get_post_views(get_the_ID()); ?>
					<?php if($view_count > 0) { ?>
						<?php if($view_count == 1){?>
							<?php echo esc_attr($view_count) .'<span>'. esc_html__(' View', 'favita').'</span>'; ?>
						<?php }else{ ?>
							<?php echo esc_attr($view_count) .'<span>'. esc_html__(' Views', 'favita').'</span>'; ?>
						<?php } ?>
					<?php }else{ ?>
						<?php echo esc_attr($view_count) .'<span>'. esc_html__(' Views', 'favita').'</span>'; ?>
					<?php } ?>
				</span>
			<?php } ?>
		</div>
<?php }
endif;
if ( ! function_exists( 'favita_time_link' ) ) :
	function favita_time_link() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%3$s, %4$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%3$s, %4$s</time><time class="updated" datetime="%6$s">%7$s</time>';
		}
		$time_string = sprintf(
			$time_string,
			get_the_date( DATE_W3C ),
			get_the_date('l'),
			get_the_date('F j'),
			get_the_date('Y'),
			get_the_date('g:i a'),
			get_the_modified_date( DATE_W3C ),
			get_the_modified_date()
		);
		return sprintf(
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);
	}
endif;